@@ -9,6 +9,11 @@ import (
 	"github.com/gobwas/glob"
 )
 
+const (
+	AllBranchesTagMode   = "all-branches"
+	CurrentBranchTagMode = "current-branch"
+)
+
 // copied from goreleaser
 
 // IsRepo returns true if current folder is a git repository
@@ -17,6 +22,12 @@ func IsRepo() bool {
 	return err == nil && strings.TrimSpace(out) == "true"
 }
 
+// Root returns the root of the git repository
+func Root() (string, error) {
+	out, err := run("rev-parse", "--show-toplevel")
+	return strings.TrimSpace(out), err
+}
+
 func getAllTags(args ...string) ([]string, error) {
 	tags, err := run(append([]string{"-c", "versionsort.suffix=-", "tag", "--sort=-version:refname"}, args...)...)
 	if err != nil {
@@ -27,7 +38,7 @@ func getAllTags(args ...string) ([]string, error) {
 
 func DescribeTag(tagMode string, pattern string) (string, error) {
 	args := []string{}
-	if tagMode == "current-branch" {
+	if tagMode == CurrentBranchTagMode {
 		args = []string{"--merged"}
 	}
 	tags, err := getAllTags(args...)
